library(nlme)
library(lattice)
library(ggplot2)
library(MASS)
library(Hmisc)

rm(list=ls())
load("tafgroup.rda") # with 62 Participants


taf <- tafgroup[, c(1,2,3,4,6,7)]
names(taf) <- c("ID", "GROUP","TASK","STOR", "PT", "PC")

#Recoding levels 
taf$TASK <-ifelse(taf$TASK == "control", 0,1)


#Grouped method
taf <- groupedData(PC ~ PT | ID, inner = ~ STOR*TASK, 
             data=taf, 
             labels=list(x = "Time (s)", y = "p(Correct)"))

taf$ID <- as.factor(taf$ID)
taf$STOR <- as.factor(taf$STOR)

taf$ID <- factor(taf$ID, levels=c("1","2","3","4","5","6","7","8","9","10","11","12",
"13","14","15","16","17","18", "19","20","21","22","23","24","25","26","27","28","29",
"30","31","32","33","34","35","36","37","38","39","40","41","42","43","44","45","46","47",
"48","49","50","51","52","53","54","55","56","57","58","59","60","61","62")) 

#codes Control=0 (control condition), go and no-go condition=1
# STOR = storage; PT: presentation time; PC= proportion of correct;
# Condition
taf$cond[(taf$STOR==1 & taf$TASK==0) ] <-  1
taf$cond[(taf$STOR==2 & taf$TASK==0) ] <-  2
taf$cond[(taf$STOR==3 & taf$TASK==0) ] <-  3
taf$cond[(taf$STOR==1 & taf$TASK==1) ] <-  4
taf$cond[(taf$STOR==2 & taf$TASK==1) ] <-  5
taf$cond[(taf$STOR==3 & taf$TASK==1) ] <-  6


# Successive differences contrasts coding for all fixed-effects (factors)
# Control -0.5 and Go-no-go 0.5
# Y = young adults, O = old adults, and Ch = children

taf$TASK <-ifelse(taf$TASK == 0, -0.5, 0.5)

taf$MD1 <-ifelse(taf$TASK == 0.5, ifelse(taf$STOR == 1, -2/3, +1/3), 0) #Necessary for test SC parameter in the Go-no-go


taf$Y.2v1 <- ifelse(taf$GROUP == "young", ifelse(taf$STOR == 1, -2/3, +1/3), 0)
taf$Y.3v2 <- ifelse(taf$GROUP == "young", ifelse(taf$STOR == 3, +2/3, -1/3), 0)
taf$O.2v1 <- ifelse(taf$GROUP == "old", ifelse(taf$STOR == 1, -2/3, +1/3), 0)
taf$O.3v2 <- ifelse(taf$GROUP == "old", ifelse(taf$STOR == 3, +2/3, -1/3), 0)
taf$Ch.2v1 <- ifelse(taf$GROUP == "children", ifelse(taf$STOR == 1, -2/3, +1/3), 0)
taf$Ch.3v2 <- ifelse(taf$GROUP == "children", ifelse(taf$STOR == 3, +2/3, -1/3), 0)

taf$Ch.Y.2v1 <- ifelse(taf$GROUP == "young" | taf$GROUP == "children", ifelse(taf$STOR == 1, -2/3, +1/3), 0)
taf$Ch.Y.3v2 <- ifelse(taf$GROUP == "young" | taf$GROUP == "children", ifelse(taf$STOR == 3, +2/3, -1/3), 0)

# 2 Reordering groups             
taf$group[(taf$ID<19)]=1            # University Students  
taf$group[(taf$ID>40)]=2            # Children
taf$group[(taf$ID>18 &taf$ID<41)]=3 # Old adults
          
# sdiff contrasts 
taf$g1 <-   -2/3                                   # First contrasts Students vs old adults
taf$g1[taf$group== 2 | taf$group== 3] <-  1/3      #
taf$g2 <- -1/3      		                           # Second contrasts Testing Students vs children
taf$g2[taf$group==3] <-  2/3		#

taf$g21 <- 1/3        	                           # Second contrasts Testing Students vs children
taf$g21[taf$group==3] <-  -2/3		#

# 3 Base function per ID (specified in taf via groupedData) 

source("FRsquared.R")

source("Fmutaf.go-no-go-sc.R")
mutaf.lis.sc <- nlsList(PC ~ Fmutaf.gonogosc(PT, cond,Y.2v1,Y.3v2,O.2v1,O.3v2,Ch.2v1,Ch.3v2,TASK,C, RATE, STD,sc,g1,g2, MD1) | ID,
              data=taf, start=c(C=0.48, RATE=1.88, STD=0.17,sc=0.55), control=nls.control(maxiter=850, minFactor= 1/4096))
pairs(mutaf.lis.sc, id=0.1) ##
plot(mutaf.lis.sc,GROUP ~  resid(.), abline=0) # 
plot(mutaf.lis.sc, ID ~ resid(.), abline=0) # ....por ID
plot(intervals(mutaf.lis.sc),layout=c(4,1)) # 95% confidence intervals by ID
plot(mutaf.lis.sc, id= 0.05,adj=-1) # Heterocedasticity 0.05

mutaf.0.sc <- nlme(mutaf.lis.sc,
           fixed = list(C+ RATE+ STD + sc ~1), start = c(0.47,1.64,  0.18,0.69),random = list(C~1),
                                          verbose=TRUE, control=list(maxIter=200))
		
		summary(mutaf.0.sc)
		coef(mutaf.0.sc)
		rs.mutaf.0.sc <- FRsquared(mutaf.0.sc, taf$PC)
		rs.mutaf.0.sc
		intervals(mutaf.0.sc)

ACF(mutaf.0.sc, form = ~1| ID )


source("Fmutaf.go-no-go.R")
mutaf.lis <- nlsList(PC ~ Fmutaf.gonogo(PT, cond,Y.2v1,Y.3v2,O.2v1,O.3v2,Ch.2v1,Ch.3v2,TASK,C, RATE, STD,g1,g2) | ID,
              data=taf, start=c(C=0.46, RATE=1.88, STD=0.17), control=nls.control(maxiter=150))
pairs(mutaf.lis, id=0.1) ##
plot(mutaf.lis,GROUP ~  resid(.), abline=0) # 
plot(mutaf.lis, ID ~ resid(.), abline=0) # ....por ID
plot(intervals(mutaf.lis),layout=c(3,1)) # 95% confidence intervals by ID
plot(mutaf.lis, id= 0.05,adj=-1) # Heterocedasticity 0.05


mutaf.0 <- nlme(mutaf.lis,
           fixed = list(C+ RATE+ STD ~1), start = c(0.47,1.64,  0.18),random = list(C ~1),
                                          verbose=TRUE, control=list(maxIter=200))
  	
		summary(mutaf.0)
		coef(mutaf.0)
		rs.mutaf.0 <- FRsquared(mutaf.0, taf$PC)
		rs.mutaf.0
		intervals(mutaf.0)

ACF(mutaf.0, form = ~1| ID )

plot(ACF(mutaf.0, form = ~1| ID ), alpha=0.05)#Autocorrelations the final model not shows this problem

source("DeltaAICBIC.R")
d<-anova(mutaf.0,mutaf.0.sc)
DeltaAICBIC(d)

mutaf.full  <- update(mutaf.0.sc,fixed = list(C ~ TASK + g1 + g2, STD  ~ TASK + g1 + g2, 
                                              sc ~ g1 + g2 + MD1, 
                                              RATE  ~ Y.2v1 + Y.3v2 + O.2v1 + 
                                              O.3v2 + Ch.2v1 + Ch.3v2 + g1 + g2),
              start = c(0.46,0,0,0,0.17,0,0,0,0.55,0,0,0,1.88,0,0,0,0,0,0,0,0),
     			  random = pdDiag(C + STD + RATE + sc ~ 1),
    			  verbose=TRUE,control=list(maxIter=500))
        
        mean(coef(mutaf.full) )
    summary(mutaf.full)
		rs.mutaf.full<-FRsquared(mutaf.full, taf$PC)
		rs.mutaf.full
		intervals(mutaf.full)

anova(mutaf.0.sc,mutaf.full)



mutaf.1  <- update(mutaf.0.sc,fixed = list(C ~ TASK + g1 + g2, STD  ~ TASK + g1 + g2, 
                                              sc ~ g1 + g2 + MD1, 
                                              RATE  ~ Y.2v1 + Y.3v2 + O.2v1 + 
                                              Ch.2v1 + Ch.3v2 + g1 + g2),
              start = c(0.46,0,0,0,0.17,0,0,0,0.55,0,0,0,1.88,0,0,0,0,0,0,0),
       		  random = pdDiag(C + STD + RATE + sc ~ 1),
    			  verbose=TRUE,control=list(maxIter=500))
        
        mean(coef(mutaf.1) )
		summary(mutaf.1)
		rs.mutaf.1<-FRsquared(mutaf.1, taf$PC)
		rs.mutaf.1
		intervals(mutaf.1)

anova(mutaf.0.sc,mutaf.full,mutaf.1)

mutaf.2  <- update(mutaf.0.sc,fixed = list(C ~ TASK + g1 + g2, STD  ~ TASK + g1 + g2, 
                                              sc ~ g1 + g2 + MD1, 
                                              RATE  ~ Y.2v1 + Y.3v2 + O.2v1 + 
                                              Ch.2v1 + Ch.3v2 + g2),
              start = c(0.46,0,0,0,0.17,0,0,0,0.55,0,0,0,1.88,0,0,0,0,0,0),
         	  random = pdDiag(C + STD + RATE + sc ~ 1),
    			  verbose=TRUE,control=list(maxIter=500))
        
        mean(coef(mutaf.2) )
		summary(mutaf.2)
		rs.mutaf.2 <-FRsquared(mutaf.2, taf$PC)
		rs.mutaf.2
		intervals(mutaf.2)

anova(mutaf.0.sc,mutaf.full,mutaf.1,mutaf.2)

mutaf.3  <- update(mutaf.0.sc,fixed = list(C ~ TASK + g1 + g2, STD  ~ TASK + g1 + g2, 
                                              sc ~ g1 + MD1, 
                                              RATE  ~ Y.2v1 + Y.3v2 + O.2v1 + 
                                              Ch.2v1 + Ch.3v2 + g2),
              start = c(0.46,0,0,0,0.17,0,0,0,0.55,0,0,1.88,0,0,0,0,0,0),
             random = pdDiag(C + STD + RATE + sc ~ 1),
    			  verbose=TRUE,control=list(maxIter=500))
        
        mean(coef(mutaf.3) )
		summary(mutaf.3)
		rs.mutaf.3 <-FRsquared(mutaf.3, taf$PC)
		rs.mutaf.3
		intervals(mutaf.3)

anova(mutaf.0.sc,mutaf.full,mutaf.1,mutaf.2,mutaf.3)

mutaf.4  <- update(mutaf.0.sc,fixed = list(C ~  g1 + g2, STD  ~ TASK + g1 + g2, 
                                              sc ~ g1 + MD1, 
                                              RATE  ~ Y.2v1 + Y.3v2 + O.2v1 + 
                                              Ch.2v1 + Ch.3v2 + g2),
              start = c(0.46,0,0,0.17,0,0,0,0.55,0,0,1.88,0,0,0,0,0,0),
             random = pdDiag(C + STD + RATE + sc ~ 1),
      		  verbose=TRUE,control=list(maxIter=500))
        
        mean(coef(mutaf.4) )
		summary(mutaf.4)
		rs.mutaf.4<-FRsquared(mutaf.4, taf$PC)
		rs.mutaf.4
		intervals(mutaf.4)

anova(mutaf.0.sc,mutaf.full,mutaf.1,mutaf.2,mutaf.3,mutaf.4)

mutaf.5  <- update(mutaf.0.sc,fixed = list(C ~  g1 + g2, STD  ~  g1 + g2, 
                                              sc ~ g1 + MD1, 
                                              RATE  ~ Y.2v1 + Y.3v2 + O.2v1 + 
                                              Ch.2v1 + Ch.3v2 + g2),
              start = c(0.46,0,0,0.17,0,0,0.55,0,0,1.88,0,0,0,0,0,0),
             random = pdDiag(C + STD + RATE + sc ~ 1),
        	  verbose=TRUE,control=list(maxIter=500))
        
        mean(coef(mutaf.5) )
		summary(mutaf.5)
		rs.mutaf.5 <-FRsquared(mutaf.5, taf$PC)
		rs.mutaf.5
		intervals(mutaf.5)

mutaf.6  <- update(mutaf.0.sc,fixed = list(C ~  g1 + g2, STD  ~  g1 + g2, 
                                              sc ~ g1 + MD1, 
                                              RATE  ~ Ch.Y.2v1 + Ch.Y.3v2 + O.2v1  
                                              + g2),
              start = c(0.46,0,0,0.17,0,0,0.55,0,0,1.88,0,0,0,0),
             random = pdDiag(C + STD + RATE + sc ~ 1),
            verbose=TRUE,control=list(maxIter=500))
        
        mean(coef(mutaf.6) )
		summary(mutaf.6)
		rs.mutaf.6 <-FRsquared(mutaf.6, taf$PC)
		rs.mutaf.6
		intervals(mutaf.6)

mutaf.7  <- update(mutaf.0.sc,fixed = list(C ~  g2, STD  ~  g1 + g2, 
                                              sc ~ g1 + MD1, 
                                              RATE  ~ Ch.Y.2v1 + Ch.Y.3v2 + O.2v1  
                                              + g2),
              start = c(0.46,0,0.17,0,0,0.55,0,0,1.88,0,0,0,0),
             random = pdDiag(C + STD + RATE + sc ~ 1),
            verbose=TRUE,control=list(maxIter=500))
        
        mean(coef(mutaf.7) )
  	summary(mutaf.7)
		rs.mutaf.7 <-FRsquared(mutaf.7, taf$PC)
		rs.mutaf.7
		intervals(mutaf.7)

a<-anova(mutaf.0.sc,mutaf.full,mutaf.1,mutaf.2,mutaf.3,mutaf.4,mutaf.5,mutaf.6,mutaf.7)

DeltaAICBIC(a)

###############################
######TESTING CORRELATIONS
###############################

mutaf.7.cor  <- update(mutaf.7,
         random = list(C + STD + RATE + sc  ~ 1),
        verbose=TRUE,control=list(maxIter=500))
    
    mean(coef(mutaf.7.cor) )
summary(mutaf.7.cor)
rs.mutaf.7.cor<-FRsquared(mutaf.7.cor, taf$PC)
rs.mutaf.7.cor
intervals(mutaf.7.cor)


b<-anova(mutaf.7,mutaf.7.cor)
DeltaAICBIC(b)

mutaf.7.cor.block  <- update(mutaf.7,
 random = pdBlocked(list(STD + RATE + sc  ~ 1,C ~ 1)),
verbose=TRUE,control=list(maxIter=500))

intervals(mutaf.7.cor.block)
summary(mutaf.7.cor.block)
rs.mutaf.7.cor.block<-FRsquared(mutaf.7.cor.block, taf$PC)
rs.mutaf.7.cor.block


#####The variance was not constant across the groups!!!
####This new models has two adittional parameters
mutaf.7.cor.block.het <- update(mutaf.7.cor.block, weights=varIdent(form=~ 1|GROUP))

save(mutaf.7.cor.block.het, file="mutaf.7.cor.block.het.rda")
mean(coef(mutaf.7.cor.block.het) )
  	summary(mutaf.7.cor.block.het)
		rs.mutaf.7.cor.block.het <-FRsquared(mutaf.7.cor.block.het, taf$PC)
		rs.mutaf.7.cor.block.het
		intervals(mutaf.7.cor.block.het)
#load("mutaf.7.cor.block.het.rda")


c<-anova(mutaf.0,mutaf.0.sc,mutaf.full, mutaf.1, mutaf.2,mutaf.3, mutaf.4, mutaf.5,
        mutaf.6, mutaf.7.cor,mutaf.7.cor.block,mutaf.7.cor.block.het)
fitting<-DeltaAICBIC(c)
fitting

#####Testing the assumptions
#### Testing asumptions in non-linear mixed-effects models (Pinheiro & Bates, 2000)
# Assumption 1: the within-group errors are independent and identically normally distributed, with mean zero and 
# variance 0^2, and they are independent o random effects. 

plot(mutaf.7.cor.block.het, ID ~ resid(.), abline=0) # this plot is useful for verifying that the errors are centered at zero, 
                                                # have constant variance across groups, and are independient of the group  
												# levels

plot(mutaf.7.cor.block.het, resid(.)~ fitted(.) | GROUP,id=0.05, cex=0.8, abline=0, layout=c(3,1)) 

# Assumption 2: the random effects are normally distributed, with mean zero and covarianze matrix (not depending
# on the group) and are independent for differents groups

qqnorm(mutaf.7.cor.block.het, ~ ranef(.), id=0.10, cex= 0.5) # normality test for random effects

pairs (mutaf.7.cor.block.het,~ ranef(.)| GROUP, layout=c(3,1))

pairs (mutaf.7.cor.block.het,~ ranef(.))

plot(mutaf.7.cor.block.het,id=0.05,cex=0.8,adj=-1) # residual vs fitted: outliers, ditributed simmetrically around 0, approximately constant variance 

###Testing autocorrelations
ACF(mutaf.7.cor.block.het, form = ~1| ID )

plot(ACF(mutaf.7.cor.block.het, form = ~1| ID ), alpha=0.05)



##########################################
## Building a dataframe for predictions 
##Students
k <-  62   # n of ID OJO la ETIQUETA es tomada en cuenta, los ID deben ser menores o iguales
l <-  2    # n of TASK
m <-  3    # n of STOR
n <- 81    # n obs per ID x TASK x STOR cell for 0 : 4 s pres time
N = k*l*n

tafpred2      <- expand.grid(ID=1:k, TASK=1:l, STOR=1:m, PT=seq(0, 4, length.out=n))
tafpred2$ID   <- factor(tafpred2$ID)

# 2 Reordering groups             
tafpred2$ID <- as.numeric(tafpred2$ID)
tafpred2$group[(tafpred2$ID<19)]=1
tafpred2$group[(tafpred2$ID>18 &tafpred2$ID<41)]=3
tafpred2$group[(tafpred2$ID>40)]=2

# Condition
tafpred2$cond[(tafpred2$STOR==1 & tafpred2$TASK==1) ] <-  1
tafpred2$cond[(tafpred2$STOR==2 & tafpred2$TASK==1) ] <-  2
tafpred2$cond[(tafpred2$STOR==3 & tafpred2$TASK==1) ] <-  3
tafpred2$cond[(tafpred2$STOR==1 & tafpred2$TASK==2) ] <-  4
tafpred2$cond[(tafpred2$STOR==2 & tafpred2$TASK==2) ] <-  5
tafpred2$cond[(tafpred2$STOR==3 & tafpred2$TASK==2) ] <-  6

#####
tafpred2$Y.2v1 <- ifelse(tafpred2$group == 1, ifelse(tafpred2$STOR == 1,  -2/3, +1/3), 0)
tafpred2$Y.3v2 <- ifelse(tafpred2$group == 1, ifelse(tafpred2$STOR == 3,  +2/3, -1/3), 0)
tafpred2$O.2v1 <- ifelse(tafpred2$group == 2, ifelse(tafpred2$STOR == 1,  -2/3, +1/3), 0)
tafpred2$O.3v2 <- ifelse(tafpred2$group == 2, ifelse(tafpred2$STOR == 3,  +2/3, -1/3), 0)
tafpred2$Ch.2v1 <- ifelse(tafpred2$group == 3, ifelse(tafpred2$STOR == 1, -2/3, +1/3), 0)
tafpred2$Ch.3v2 <- ifelse(tafpred2$group == 3, ifelse(tafpred2$STOR == 3, +2/3, +1/3), 0)

tafpred2$Ch.Y.2v1 <- ifelse(tafpred2$group == 1 | tafpred2$group == 2, ifelse(tafpred2$STOR == 1, -2/3, +1/3), 0)
tafpred2$Ch.Y.3v2 <- ifelse(tafpred2$group == 1 | tafpred2$group == 2, ifelse(tafpred2$STOR == 3, +2/3, -1/3), 0)



#Sliding Contrasts for Condition
tafpred2$TASK <-ifelse(tafpred2$TASK == 1, -0.5, 0.5)

tafpred2$MD1 <-ifelse(tafpred2$TASK == 0.5, ifelse(tafpred2$STOR == 1, -2/3, +1/3), 0)
#Sliding Contrasts for Condition
tafpred2$g1 <-   -2/3                                   # First contrasts Students vs old adults
tafpred2$g1[tafpred2$group== 2 | tafpred2$group== 3] <-  1/3      #
tafpred2$g2 <- -1/3					                           # Second contrasts Testing Students vs children
tafpred2$g2[tafpred2$group==3] <-  2/3		#

#Predicctions

tafpred2$PC <- predict(mutaf.7.cor.block.het, tafpred2, level=1)
taf1 <- taf
tafpred <-tafpred2
tafpred2 <- tafpred2[tafpred2$PC>.00,]

#Saving tafpred2 as "plotgroup" for doing predictions by age group 
plotgroup <-tafpred2

#Saving tafobs2 as tafobs3 for doing predictions by age group 
tafobs2 <- taf1[, c(1,3:5,2,7,14,8:13,15,16,6)]
tafobs3 <- tafobs2 #Saving tafobs2 as tafobs3 for doing p

plotgroup$group <- factor(plotgroup$group, levels=c("1","2","3"), labels=list("Young adults", "Children","Old adults")) 

plotgroup$TASK <- factor(plotgroup$TASK, levels=c(-0.5,0.5), labels=list("Control", "Go-/no-go")) 

tafobs3$GROUP <- factor(tafobs3$GROUP, levels=c("young","old","children"), labels=list("Young adults", "Old adults","Children")) 

tafobs3$TASK <- factor(tafobs3$TASK, levels=c(-0.5,0.5), labels=list("Control", "Go-/no-go")) 


plotgroup <- aggregate(plotgroup$PC, by=data.frame(plotgroup$PT, plotgroup$TASK, 
                                plotgroup$STOR,plotgroup$group), mean, na.rm=TRUE)

names(plotgroup) <- c("PT","TASK", "STOR","GROUP","PC")


   
tafobs3 <- aggregate(tafobs3$PC, by=data.frame(tafobs3$PT, tafobs3$TASK, tafobs3$STOR,
                                tafobs3$GROUP),mean, na.rm=TRUE)

names(tafobs3) <- c("PT","TASK", "STOR","GROUP","PC")


tafplot3 <- rbind(tafobs3,plotgroup)  
tafplot3$op <- c(rep(100, nrow(tafobs3)), rep(200, nrow(plotgroup) ))
tafplot3$op <- factor(tafplot3$op + 10*as.numeric(tafplot3$TASK) + as.numeric(tafplot3$STOR))




##Generating a plot#####
#Plot 1
xyplot(PC ~ PT |GROUP*TASK, data=tafplot3, groups = op, layout=c(3,2),
        panel = panel.superpose.2,
        cex = 0.7,
        type = c("p","p","p","p","p","p","l","l", "l", "l", "l", "l"),
        pch=c(1:4,8,6),col=c(1,1,1,12,12,12), lty = 1, 
        key = list(space = "right", columns = 1,col=c(1,1,1,12,12,12),points= list(pch =c(1:4,8,6)), 
        text = list(c("G-1","G-2","G-3","GNG-1","GNG-2","GNG-3"))),
        ylab = "Proportion correct", xlab = "Presentation time (s)",main= 
        "Time-Accuracy Functions by Group",xlim=c(0,4),
        strip = strip.custom(strip.levels= c(TRUE,TRUE), strip.names= c(TRUE,FALSE),
        par.strip.text=list(cex=0.9,col="black"),var.name= c("Group","Memory Demand"),bg="grey90"))


###Figura Articulo updating cost
xyplot(PC ~ PT |GROUP + TASK, data=tafplot3, groups = op, layout=c(3,2),
        panel= panel.superpose.2, as.table=TRUE,
        cex = 1,
        type = c("p","p","p","p","p","p","l","l", "l", "l", "l", "l"),
        pch=c(15,16,17,1,2,3),col=c(1,1,1,1,1,1), lty = c(1,1,1,5,5,5), 
        key = list(space = "top", columns = 6,col=c(1,1,1,1,1,1),points= list(pch =c(15,16,17,1,2,3)),
        lty = c(1,1,1,5,5,5),lines= TRUE, title= "",cex= 0.9, background=FALSE,border=FALSE,
        text = list(c("Control-1","Control-2","Control-3","Go and no-go-1","Go and no-go-2","Go and no-go-3"))),
        scales= list(y= list(alternating=3), x= list(tick.number=  10)),main=NULL,
        ylab = "Proportion correct",xlab = "Presentation time (s)", xlim=c(0,4),
        strip = strip.custom(strip.levels= c(TRUE,TRUE), strip.names= c(TRUE,FALSE),
        par.strip.text=list(cex=1,col="black"),var.name= c("Group","Memory Demand"),bg="grey90"))


###Figura Articulo updating cost
xyplot(PC ~ PT |GROUP + STOR, data=tafplot3, groups = op, layout=c(3,3),
        panel= panel.superpose.2, as.table=TRUE,
        cex = 1.5,
        type = c("p","p","p","p","p","p","l","l", "l", "l", "l", "l"),
        pch=c(15,16,17,1,2,3),col=c(1,1,1,1,1,1), lty = c(1,1,1,5,5,5), 
        key = list(space = "top", columns = 6,col=c(1,1,1,1,1,1),points= list(pch =c(15,16,17,1,2,3)),
        lty = c(1,1,1,5,5,5),lines= TRUE, title= "",cex= 1.5, background=FALSE,border=FALSE,
        text = list(c("Control-1","Control-2","Control-3","Go-/no-go-1","Go/no-go-2","Go-/no-go-3"))),
        scales= list(y= list(alternating=3), x= list(tick.number=  10)),main=NULL,
        ylab = list("Proportion correct",cex=1.5),xlab = list("Presentation time (s)",cex=1.5), ylim=c(0.0,1),xlim=c(0,4),
        strip = strip.custom(strip.levels= c(TRUE,TRUE), strip.names= c(TRUE,FALSE),
        par.strip.text=list(cex=1.1,col="black"),var.name= c("Group","MD"),bg="grey90"))



###Figura Articulo updating cost
xyplot(PC ~ PT |GROUP + STOR, data=tafplot3, groups = op, layout=c(3,3),
        panel= panel.superpose.2, as.table=TRUE,
        cex = 1.7,
        type = c("p","p","p","p","p","p","l","l", "l", "l", "l", "l"),
        pch=c(15,16,17,1,2,3),col=c(1,1,1,1,1,1), lty = c(1,1,1,5,5,5), 
        key = list(space = "top", columns = 6,col=c(1,1,1,1,1,1),points= list(pch =c(15,16,17,1,2,3)),
        lty = c(1,1,1,5,5,5),lines= TRUE, title= "",cex= 1.1, background=FALSE,border=FALSE,
        text = list(c("Control-1","Control-2","Control-3","Go/nogo-1","Go/nogo-2","Go/nogo-3"), cex=0.9)),
        scales= list(y= list(alternating=3), x= list(tick.number=  10)),main=NULL,
        ylab = list("Proportion correct",cex=1.5),xlab = list("Presentation time (s)",cex=1.5), ylim=c(0.0,1),xlim=c(0.0,4),
        strip = strip.custom(strip.levels= c(TRUE,TRUE), strip.names= c(TRUE,FALSE),
        par.strip.text=list(cex=1,col="black"),var.name= c("Group","Memory demand"),bg="grey90"))
