library(nlme)
library(lattice)
library(ggplot2)
library(MASS)
library(Hmisc)

#setwd("~/R")
rm(list=ls())
load("tafgroup.rda") # with 62 Participants


taf <- tafgroup[, c(1,2,3,4,6,7)]
names(taf) <- c("ID", "GROUP","TASK","STOR", "PT", "PC")

#Recoding levels 
taf$TASK <-ifelse(taf$TASK == "control", 0,1)


#Grouped method
taf <- groupedData(PC ~ PT | ID, inner = ~ STOR*TASK, 
             data=taf, 
             labels=list(x = "Time (s)", y = "p(Correct)"))

taf$ID <- as.factor(taf$ID)
taf$STOR <- as.factor(taf$STOR)

taf$ID <- factor(taf$ID, levels=c("1","2","3","4","5","6","7","8","9","10","11","12",
"13","14","15","16","17","18", "19","20","21","22","23","24","25","26","27","28","29",
"30","31","32","33","34","35","36","37","38","39","40","41","42","43","44","45","46","47",
"48","49","50","51","52","53","54","55","56","57","58","59","60","61","62")) 

#codes Control=0 (control condition), go and no-go condition=1
# STOR = storage; PT: presentation time; PC= proportion of correct;
# Condition
taf$cond[(taf$STOR==1 & taf$TASK==0) ] <-  1
taf$cond[(taf$STOR==2 & taf$TASK==0) ] <-  2
taf$cond[(taf$STOR==3 & taf$TASK==0) ] <-  3
taf$cond[(taf$STOR==1 & taf$TASK==1) ] <-  4
taf$cond[(taf$STOR==2 & taf$TASK==1) ] <-  5
taf$cond[(taf$STOR==3 & taf$TASK==1) ] <-  6


# Successive differences contrasts coding for all fixed-effects (factors)
# Control -0.5 and Go-no-go 0.5
# Y = young adults, O = old adults, and Ch = children

taf$TASK <-ifelse(taf$TASK == 0, -0.5, 0.5)

taf$MD1 <-ifelse(taf$TASK == 0.5, ifelse(taf$STOR == 1, -2/3, +1/3), 0) #Necessary for test SC parameter in the Go-no-go


taf$Y.2v1 <- ifelse(taf$GROUP == "young", ifelse(taf$STOR == 1, -2/3, +1/3), 0)
taf$Y.3v2 <- ifelse(taf$GROUP == "young", ifelse(taf$STOR == 3, +2/3, -1/3), 0)
taf$O.2v1 <- ifelse(taf$GROUP == "old", ifelse(taf$STOR == 1, -2/3, +1/3), 0)
taf$O.3v2 <- ifelse(taf$GROUP == "old", ifelse(taf$STOR == 3, +2/3, -1/3), 0)
taf$Ch.2v1 <- ifelse(taf$GROUP == "children", ifelse(taf$STOR == 1, -2/3, +1/3), 0)
taf$Ch.3v2 <- ifelse(taf$GROUP == "children", ifelse(taf$STOR == 3, +2/3, -1/3), 0)

taf$Ch.Y.2v1 <- ifelse(taf$GROUP == "young" | taf$GROUP == "children", ifelse(taf$STOR == 1, -2/3, +1/3), 0)
taf$Ch.Y.3v2 <- ifelse(taf$GROUP == "young" | taf$GROUP == "children", ifelse(taf$STOR == 3, +2/3, -1/3), 0)

# 2 Reordering groups             
taf$group[(taf$ID<19)]=1            # University Students  
taf$group[(taf$ID>40)]=2            # Children
taf$group[(taf$ID>18 &taf$ID<41)]=3 # Old adults
          
# sdiff contrasts 
taf$g1 <-   -2/3                                   # First contrasts Students vs old adults
taf$g1[taf$group== 2 | taf$group== 3] <-  1/3      #
taf$g2 <- -1/3        	                           # Second contrasts Testing Students vs children
taf$g2[taf$group==3] <-  2/3		#
# 3 Base function per ID (specified in taf via groupedData) 

#Addition KO 1. 2. 2012
  cmat <- matrix(0,3,2)
  cmat[1,1] <- -2/3
  cmat[2:3,1] <- 1/3
  cmat[c(1,2),2] <- -1/3
  cmat[3,2] <- 2/3
  round(t(ginv(cmat)))


source("Rsquared.R")

source("Fmutaf.go-no-go-sc.R")
mutaf.lis.sc <- nlsList(PC ~ Fmutaf.gonogosc(PT, cond,Y.2v1,Y.3v2,O.2v1,O.3v2,Ch.2v1,Ch.3v2,TASK,C, RATE, STD,sc,g1,g2, MD1) | ID,
              data=taf, start=c(C=0.48, RATE=1.88, STD=0.17,sc=0.55), control=nls.control(maxiter=850, minFactor= 1/4096))
pairs(mutaf.lis.sc, id=0.1) ##
plot(mutaf.lis.sc,GROUP ~  resid(.), abline=0) # 
plot(mutaf.lis.sc, ID ~ resid(.), abline=0) # ....por ID
plot(intervals(mutaf.lis.sc),layout=c(4,1)) # 95% confidence intervals by ID
plot(mutaf.lis.sc, id= 0.05,adj=-1) # Heterocedasticity 0.05

mutaf.0.sc <- nlme(mutaf.lis.sc,
           fixed = list(C+ RATE+ STD + sc ~1), start = c(0.47,1.64,  0.18,0.69),random = list(C~1),
                                          verbose=TRUE, control=list(maxIter=200))
		
		summary(mutaf.0.sc)
		coef(mutaf.0.sc)
		rs.mutaf.0.sc <- Rsquared(mutaf.0.sc, taf$PC)
		rs.mutaf.0.sc
		intervals(mutaf.0.sc)

ACF(mutaf.0.sc, form = ~1| ID )


mutaf.full  <- update(mutaf.0.sc,fixed = list(C ~ TASK + g1 + g2, STD  ~ TASK + g1 + g2, 
                                              sc ~ g1 + g2 + MD1, 
                                              RATE  ~ Y.2v1 + Y.3v2 + O.2v1 + 
                                              O.3v2 + Ch.2v1 + Ch.3v2 + g1 + g2),
              start = c(0.46,0,0,0,0.17,0,0,0,0.55,0,0,0,1.88,0,0,0,0,0,0,0,0),
     			  random = pdDiag(C + STD + RATE + sc ~ 1),
    			  verbose=TRUE,control=list(maxIter=500))
        
        mean(coef(mutaf.full) )
    summary(mutaf.full)
		rs.mutaf.full<-Rsquared(mutaf.full, taf$PC)
		rs.mutaf.full
		intervals(mutaf.full)

anova(mutaf.0.sc,mutaf.full)



mutaf.7  <- update(mutaf.0.sc,fixed = list(C ~  g2, STD  ~  g1 + g2, 
                                              sc ~ g1 + MD1, 
                                              RATE  ~ Ch.Y.2v1 + Ch.Y.3v2 + O.2v1  
                                              + g2),
              start = c(0.46,0,0.17,0,0,0.55,0,0,1.88,0,0,0,0),
             random = pdDiag(C + STD + RATE + sc ~ 1),
            verbose=TRUE,control=list(maxIter=500))
        
        mean(coef(mutaf.7) )
  	summary(mutaf.7)
		rs.mutaf.7 <-Rsquared(mutaf.7, taf$PC)
		rs.mutaf.7
		intervals(mutaf.7)



###############################
######TESTING CORRELATIONS
###############################

mutaf.7.cor  <- update(mutaf.7,
         random = list(C + STD + RATE + sc  ~ 1),
        verbose=TRUE,control=list(maxIter=500))
    
    mean(coef(mutaf.7.cor) )
summary(mutaf.7.cor)
rs.mutaf.7.cor<-Rsquared(mutaf.7.cor, taf$PC)
rs.mutaf.7.cor

anova(mutaf.7,mutaf.7.cor)

mutaf.7.cor.block  <- update(mutaf.7,
 random = pdBlocked(list(STD + RATE + sc  ~ 1,C ~ 1)),
verbose=TRUE,control=list(maxIter=500))

intervals(mutaf.7.cor.block)
summary(mutaf.7.cor.block)
rs.mutaf.7.cor.block<-Rsquared(mutaf.7.cor.block, taf$PC)
rs.mutaf.7.cor.block


#####The variance was not constant across the groups!!!
####This new models has two adittional parameters
mutaf.7.cor.block.het <- update(mutaf.7.cor.block, weights=varIdent(form=~ 1|GROUP))
#load("mutaf.7.cor.block.het.rda")
#save(mutaf.7.cor.block.het, file="mutaf.7.cor.block.het.rda")
mean(coef(mutaf.7.cor.block.het) )
  	summary(mutaf.7.cor.block.het)
		rs.mutaf.7.cor.block.het <-Rsquared(mutaf.7.cor.block.het, taf$PC)
		rs.mutaf.7.cor.block.het
		intervals(mutaf.7.cor.block.het)




